Introduction to distributed ML with PyTorch
===============================================

.. include:: ../../../tutorials/distributed-ml/torch-tutorial-0-basics/README.md
   :parser: myst_parser.sphinx_
   :start-line: 2

train.py
++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-0-basics/train.py
   :language: python
